#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.5
visibility:           public
id:                   skylighting-core-0.14.5-yRNdCV3DmY7URzt1JY2gM
key:                  skylighting-core-0.14.5-yRNdCV3DmY7URzt1JY2gM
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  3053f1bb596d6c9c9479accd51628b43
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.5-yRNdCV3DmY7URzt1JY2gM
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    attoparsec-0.14.4-DVQW3zaPrEjFLUvmkAZYCq base-4.18.2.1
    base64-bytestring-1.2.1.0-C0qMqvh3vbu1LTlZEUtx0r binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    colour-2.3.7-xhIDZ6j0j1vTiLcOK4Oo containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe text-2.0.2 transformers-0.6.1.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xml-conduit-1.9.1.4-G1f8ph4UiTy8fbgaTyNDq

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

